#
# spec file for package perl-IO
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-IO
Version:        1.39
Release:        1.1
%define cpan_name IO
Summary:        Load Various Io Modules
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/IO/
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
'IO' provides a simple mechanism to load several of the IO modules in one
go. The IO modules belonging to the core are:

      IO::Handle
      IO::Seekable
      IO::File
      IO::Pipe
      IO::Socket
      IO::Dir
      IO::Select
      IO::Poll

Some other IO modules don't belong to the perl core but can be loaded as
well if they have been installed from CPAN. You can discover which ones
exist by searching for "^IO::" on http://search.cpan.org.

For more information on any of these modules, please see its respective
documentation.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc ChangeLog README

%changelog
* Fri Apr 20 2018 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-IO/ChangeLog
  IO 1.38 -- Apr 19 2018 - Todd Rinaldo
  * Remove pre 5.8 logic from code base.
  * Bump all IO modules to 1.38 and set required Perl to 5.8.1
  * Fix for perl #125723
  * IO test: adjust require for non CORE perl
  * IO::Handle - fix precedence issue
  * Document IO::Select error detection
  * Rely on C89 <time.h>
  * (perl #130856) deal with unpack_sockaddr_un() croaking
  * Switch most open() calls to three-argument form.
  * (perl #129788) IO::Poll: fix memory leak
  * (perl #128095) check pack_sockaddr_un()'s return value
  * dist/: remove . from @INC when loading optional modules
  * Fix IO::Handle documentation mangled by a manually applied patch
  * Make IO::Poll->poll call _poll even with an empty fd array
  * Fix assertion when calling IO::Poll::_poll() with an empty fd array
  * Some BSD implementations might have <sys/poll.h> instead of <poll.h>.
  IO 1.36 -- Jun 26 2015 (Not released to CPAN)
  * dist/IO/t/io_utf8argv.t: Generalize for non-ASCII platforms.
  * VMS does have fsync, so configure accordingly.
  * Skip obsolete skip in io_xs.t.
  * Label conditionally unused.
  * Use <sys/poll.h> if available before going select().
  * Fix assertion when calling IO::Poll::_poll() with an empty fd array
  * Make IO::Poll->poll call _poll even with an empty fd array
  IO 1.35 -- Dec 7 2014 (Not released to CPAN)
  * Change OP_SIBLING to OpSIBLING
  * Improve connected() doc
  * IRIX: fsync documented to fail on read-only filehandles.
  * Convert all use of Test.pm to Test::More
  IO 1.34 -- Sep 10 2014 (Not released to CPAN)
  * Add dual life support for use of op_sibling in IO.xs
  IO 1.33 -- Jun 10 2014 (Not released to CPAN)
  * wrap op_sibling field access in OP_SIBLING* macros
  * Make like() and unlike() in t/test.pl refuse non-qr// arguments
  * Further simplify the sockatmark(). (And do not assign the fd in PREINIT.)
  IO 1.32 -- May 29 2014 (Not released to CPAN)
  * fcntl receiving -1 from fileno, fcntl failing.
  * Also very few spots of negative numgroups for getgroups(), and fgetc() return, but almost all checking is for fcntl.
  * merged fix for perl #121743 and perl #121745: hopefully picked up all the fixes-to-fixes from the ticket.
  * Fix for Coverity perl5 CIDs 28990..29003,29005..29011,29013,45354,45363,49926
  * Argument cannot be negative (NEGATIVE_RETURNS) fd is passed to a parameter that cannot be negative.
  * CIDs 29004, 29012: Argument cannot be negative (NEGATIVE_RETURNS) num_groups is passed to a parameter that cannot be negative and because of CIDs 29005 and 29006 also CID 28924.
  * In the first set of issues a fd is retrieved from PerlIO_fileno, and that is then used in places like fstat(), fchown(), dup(), etc., without checking whether the fd is valid (>=0).
  * In the second set of issues a potentially negative number is potentially passed to getgroups().
  * The CIDs 29005 and 29006 were a bit messy: fixing them needed also resolving CID 28924 where the return value of fstat() was ignored, and for completeness adding two croak calls (with perldiag updates): a bit of a waste since it's suidperl code.
  IO 1.31 -- Mar 4 2014 (Not released to CPAN)
  * dist/IO: Allow to be dual-lived - This dual-lived module has not been able to be compiled on releases earlier than 5.10.1.
  * IO::Socket::INET: Handle getprotobyn{ame,umber} not being available
  * dist/IO/t/io_pipe.t: Work around android only having an inbuilt echo
  * Add examples for IO::Socket::UNIX.
  * Remove an old note about autoflush from the POD.
  * ioctl on perlhost platforms take a char*, not void*
  IO 1.30 --  Nov 13 2013 (Not released to CPAN)
  * IO.xs: fix compiler warning
  * [perl #75156] fix the return value and bits for removing a closed fh
  * [perl #75156] tests for deleting a closed handle from IO::Select
  * Fix IO::Socket::connect() in the light of $! changes
  IO 1.29 -- Mar 15 2013 (Not released to CPAN)
  * Use separate macros for byte vs uv Unicode
  * IO::Socket::INET's documentation for its Listen parameter was somewhat misleading, and the documentation for IO::Socket::Unix even more so.
  * Address [perl #117999] for now by skipping known bad test on AIX
  * [perl #117791] Clarify that write does not match the C 'write' semantics
  * fix dist/IO/t/cachepropagate-unix.t
  IO 1.28 -- Feb 2 2013 (Not released to CPAN)
  * dist/IO/IO.xs: Silence compiler warning. This variable is unused, doesn't need to be declared.
  IO 1.27 -- Feb 17 2013 (Not released to CPAN)
  * [perl #116322]: getc() and ungetc() with unicode failure (ungetc() had no knowledge of UTF-8. )
  IO 1.26 -- May 13 2009 - Jan 16 2013 (Not released to CPAN)
  * portability to Haiku-OS for the cachepropagate-*.t tests
  * sync() on a read-only file handle doesn't work on cygwin either
  * [rt.cpan.org #61577] VMS doesn't support UNIX sockets
  * add Test::More as a prereq to Makefile.PL
  * document the limitations of protocol(), sockdomain(), socktype()
  * [rt.cpan.org #61577] try to populate socket info when not cached
  * [rt.cpan.org #61577] propagate socket details on accept
  * [rt.cpan.org #61577] sockdomain and socktype undef on newly accepted sockets
  * [perl #64772] check both input and output file handles for sync (This allows sync() to be called on directory handles.)
  * [perl #64772] TODO test for sync on read only handle
  * Convert some tests to Test::More
  * Correct bug report email in docs from perl5-porters@perl.org to perlbug@perl.org
  * Remove ‘use File::Spec’ from IO::File (It is not using it any more.)
  * [RT #36079] Convert ` to '.
  * use :raw to avoid interference from PERL_UNICODE when creating test data
  * Make IO::Handle::getline(s) respect the open pragma (RT 66474)
  * Fix setting sockets nonblocking in Win32
  * Use the exception set in select (connect()) to early return when remote end is busy or in non existing port
  * Keep verbatim pod within 79 cols
  * Keep verbatim pod in IO.pm within 80 cols
  * [perl #88486] IO::File does not always export SEEK*
  * Explicitly force the load of IO::File in IO::Handle (see the discussion in [perl #87940]).
  * Remove various indirect method calls in IO's docs
  * IO::Select: allow removal of IO::Handle objects without fileno
  * Actuall excise 'Apollo DomainOS' support. We officially killed it in 5.11.0. It hadn't worked for years before that.
  * fix various compiler warnings from XS code (void return value)
  * Only bind to localhost in tests: "in general, tests shouldn't be listening on all interfaces."
  * Document IO::Socket getsockopt and setsockopt
  * Convert sv_2mortal(newSVpvn()) to newSVpvn_flags(), for 5.11.0 and later. (
  * Minor documentation and typo fixes.
  * Move IO from ext to dist in core perl
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Fri Jun 26 2009 chris@computersalat.de
- update to 1.25
- IO 1.25 -- Wed May 13 18:37:33 CDT 2009
  * Fix test warnings in io_dir
  * skip tests known to cause a segfault 5.10.0
- IO 1.24 -- Mon May 11 14:15:51 CDT 2009
  * Make Makefile.PL usable by core and CPAN
  * Reorganize files to be under lib/ directory structure now matches core perl
  * Update with following changes made to core perl distribution
  * Silence Win32 compiler warning in IO.xs
  * Make non-blocking mode work on Windows in IO::Socket::INET
  * fix some missing parts of IO::Handle pod
  * Implement IO::Handle::say the same way as the builtin say().
  * Undo io_linenum.t part of #34148. It was io_multihomed.t
    that I meant (my mistake), and that is now covered by #34155.
  * watchdog() some IO tests
  * Some more missing isGV_with_GP()s
  * IO::Dir destructor
  * IO::Socket::INET unnecessarily resolves "udp"
  * IO::Handle->say should ignore $\ (bug #49266)
  * consting IO.xs
  * Net::SMTP can't send large messages with bleadperl
  * Fix for IO::Socket send method
  * Fixes for the test suite on OS/2
  * Silence VC++ compiler warnings
  * IO::Socket's IO.xs fails to compile
  * IO::Socket::connect returns wrong errno on timeout
  * Coverity correctly reports that gv might (just) be NULL. So don't derefernece it if it is.
  * Simplify tests for fork() capabilities
  * Fix syntax error in io_pipe test
  * Making IO::Socket pass test on Win32
  * ext/IO/t/io_unix.t
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o added header
  o clean up code
